@@ -2,7 +2,6 @@ import os
 import logging
 import time
 import click
-import ast
 from dbt_cloud import DbtCloudRunStatus
 from dbt_cloud.command import (
     DbtCloudJobGetCommand,
@@ -18,18 +17,12 @@ from dbt_cloud.command import (
     DbtCloudRunCancelCommand,
     DbtCloudJobListCommand,
     DbtCloudProjectListCommand,
+    DbtCloudEnvironmentListCommand,
 )
 from dbt_cloud.demo import data_catalog
 from dbt_cloud.serde import json_to_dict, dict_to_json
 from dbt_cloud.exc import DbtCloudException
-
-
-class PythonLiteralOption(click.Option):
-    def type_cast_value(self, ctx, value):
-        try:
-            return ast.literal_eval(value)
-        except:
-            raise click.BadParameter(value)
+from dbt_cloud.field import PythonLiteralOption
 
 
 def execute_and_print(command, **kwargs):
@@ -67,6 +60,11 @@ def project():
     pass
 
 
+@dbt_cloud.group(help="dbt Cloud environment commands")
+def environment():
+    pass
+
+
 @dbt_cloud.group(help="dbt Cloud Metadata API commands")
 def metadata():
     pass
@@ -279,6 +277,13 @@ def list(**kwargs):
     response = execute_and_print(command)
 
 
+@environment.command(help=DbtCloudEnvironmentListCommand.get_description())
+@DbtCloudEnvironmentListCommand.click_options
+def list(**kwargs):
+    command = DbtCloudEnvironmentListCommand.from_click_options(**kwargs)
+    response = execute_and_print(command)
+
+
 @metadata.command(help=DbtCloudMetadataQueryCommand.get_description())
 @click.option(
     "-f",
